==> ifrit_3.0.5.orig.tar.gz: ifrit-3.0.5/shells/generic/iggpageobject.h <==
/*=========================================================================

  Program:   Ionization FRont Interactive Tool (IFRIT)
  Language:  C++


Copyright (c) 2002-2006 Nick Gnedin 
All rights reserved.

This file may be distributed and/or modified under the terms of the
GNU General Public License version 2 as published by the Free Software
Foundation and appearing in the file LICENSE.GPL included in the
packaging of this file.

THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS ``AS IS''
AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
ARE DISCLAIMED. IN NO EVENT SHALL THE AUTHORS OR CONTRIBUTORS BE LIABLE FOR
ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.

=========================================================================*/

//
//  A page containing volume widgets
//

#ifndef IGGPAGEOBJECT_H
#define IGGPAGEOBJECT_H


#include "iggpagemain.h"


class iViewModule;
class iViewObject;

class iggDataTypeProvider;


class iggPageObject : public iggPageMain
{

public:

	iggPageObject(iggFrameBase *parent, int type);
	virtual ~iggPageObject();

	virtual const iViewModule* GetViewModule() const;
	virtual iViewObject* GetViewObject() const;

	inline iggDataTypeProvider* GetProvider() const { return mProvider; }

protected:

	virtual iggFrame* CreateFlipFrame(iggFrameBase *parent) const;

	iggDataTypeProvider *mProvider, *mScalarFieldProvider;
	const int mType;
};

#endif  // IGGPAGEOBJECT_H

==> ifrit_3.2.0.orig.tar.gz: ifrit-3.2.0/shells/generic/iggpageobject.h <==
/*=========================================================================

  Program:   Ionization FRont Interactive Tool (IFRIT)
  Language:  C++


Copyright (c) 2002-2006 Nick Gnedin 
All rights reserved.

This file may be distributed and/or modified under the terms of the
GNU General Public License version 2 as published by the Free Software
Foundation and appearing in the file LICENSE.GPL included in the
packaging of this file.

THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS ``AS IS''
AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
ARE DISCLAIMED. IN NO EVENT SHALL THE AUTHORS OR CONTRIBUTORS BE LIABLE FOR
ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.

=========================================================================*/

//
//  A page containing volume widgets
//

#ifndef IGGPAGEOBJECT_H
#define IGGPAGEOBJECT_H


#include "iggpagemain.h"


class iViewModule;
class iViewObject;

class iggDataTypeProvider;


class iggPageObject : public iggPageMain
{

public:

	iggPageObject(iggFrameBase *parent, int type);
	virtual ~iggPageObject();

	virtual const iViewModule* GetViewModule() const;
	virtual iViewObject* GetViewObject() const;

	inline iggDataTypeProvider* GetProvider() const { return mProvider; }

protected:

	virtual iggFrame* CreateFlipFrame(iggFrameBase *parent) const;

	iggDataTypeProvider *mProvider, *mScalarProvider;
	const int mType;
};

#endif  // IGGPAGEOBJECT_H
